@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
@@ -12,13 +11,23 @@
 // template<> struct char_traits<char32_t>
 
 // static void assign(char_type& c1, const char_type& c2);
+// constexpr in C++17
 
 #include <string>
 #include <cassert>
 
 #include "test_macros.h"
 
-int main()
+#if TEST_STD_VER > 14
+constexpr bool test_constexpr()
+{
+    char32_t c = U'1';
+    std::char_traits<char32_t>::assign(c, U'a');
+    return c == U'a';
+}
+#endif
+
+int main(int, char**)
 {
 #ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
 #if TEST_STD_VER >= 11
@@ -26,5 +35,11 @@ int main()
     std::char_traits<char32_t>::assign(c, U'a');
     assert(c == U'a');
 #endif
+
+#if TEST_STD_VER > 14
+    static_assert(test_constexpr(), "" );
+#endif
 #endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
+
+  return 0;
 }
